@@ -2,6 +2,6 @@
   packageStartupMessage(
     paste("This is ShinyItemAnalysis version "), packageVersion("ShinyItemAnalysis"),
     "\n- to run the interactive {shiny} app, call `run_app()`",
-    "\n- to learn more, visit \"www.ShinyItemAnalysis.org\""
+    "\n- to learn more, visit `ShinyItemAnalysis.org`"
   )
 }
